/****************************************************************************
 *                                                                          
 * Title:   Setting the burst mode with external source
 *
 * Purpose: This example shows how to set burst mode with external source.
 *
 ****************************************************************************/

#include <ansi_c.h>
#include "rssiam.h"

/*** Macros & definitions ***************************************************/

#define CHECKERR( fCal ) \
    { \
        fCalStartTime = clock();\
        error = (fCal);\
        status = error;\
        printf(" Line %ld (%ld ms): %s\n", __LINE__,\
            (fCalTime = (clock() - fCalStartTime)), #fCal);\
        if (error != VI_SUCCESS)\
            {\
            rssiam_error_message (io, error, error_message);\
            printf("\tFunction Call Status: 0x%08X, %s\n", error, error_message);\
            rssiam_error_query(io, &error, error_message);\
            printf("\tInstrument Error: 0x%X, %s\n", error, error_message);\
            }\
    }

#define RESOURCE_NAME   "am" // "USB::0xAAD::0x5::100011" // Resource name

/*** Main *******************************************************************/

int main (int argc, char *argv[])
{
    ViStatus    error               = VI_SUCCESS,
                status              = VI_SUCCESS;
    clock_t     fCalTime            = 0,
                fCalStartTime       = 0;
    ViChar      error_message[256];
    ViSession   io;

    /* Define remote connection parameters (as default values) */

    ViBoolean   IDQuery             = VI_TRUE,
                resetDevice         = VI_TRUE;
    ViRsrc      resourceName        = RESOURCE_NAME;

    CHECKERR (rssiam_init (resourceName, IDQuery, resetDevice, &io));

    printf (

    "\n --- Set Burst Mode -----------------------------------------------------\n\n"
    "\t - Carrier Frequency: 1000.0 Hz\n"
    "\t - Function: Sine\n"
    "\t - Burst Source: External (Rear Trig/Gate In connector)\n"
    "\t - No. of Bursts: 3\n"
    "\n ------------------------------------------------------------------------\n\n"

    );

    /* Waweform setup */
    CHECKERR (rssiam_freq (io, 1000.0));
    CHECKERR (rssiam_funcShap (io, RSSIAM_OUTPUT_FUNC_SIN));
    CHECKERR (rssiam_outpSetup (io, RSSIAM_OUTPUT_SETUP_ON));

    /* Trigger setup */
    CHECKERR (rssiam_trigSour (io, RSSIAM_TRIGGER_SOUR_EXT));

    /* Burst setup */
    CHECKERR (rssiam_bmSour (io, RSSIAM_BM_SOUR_TRIG));
    CHECKERR (rssiam_bmNcyc (io, 3));
    CHECKERR (rssiam_bmStat (io, RSSIAM_BM_STAT_ON));

    printf ("\n");

    CHECKERR (rssiam_close (io));

    return 0;
}
