/****************************************************************************
 *                                                                          
 * Title:   Uncoupled Channel Mode
 *
 * Purpose: This example shows how to set two different waveforms with
 *          different frequencies on both channels.
 *
 ****************************************************************************/

#include <ansi_c.h>
#include "rssiam.h"

/*** Macros & definitions ***************************************************/

#define CHECKERR( fCal ) \
    { \
        fCalStartTime = clock();\
        error = (fCal);\
        status = error;\
        printf(" Line %ld (%ld ms): %s\n", __LINE__,\
            (fCalTime = (clock() - fCalStartTime)), #fCal);\
        if (error != VI_SUCCESS)\
            {\
            rssiam_error_message (io, error, error_message);\
            printf("\tFunction Call Status: 0x%08X, %s\n", error, error_message);\
            rssiam_error_query(io, &error, error_message);\
            printf("\tInstrument Error: 0x%X, %s\n", error, error_message);\
            }\
    }

#define RESOURCE_NAME   "am" // "USB::0xAAD::0x5::100011" // Resource name

/*** Main *******************************************************************/

int main (int argc, char *argv[])
{
    ViStatus    error               = VI_SUCCESS,
                status              = VI_SUCCESS;
    clock_t     fCalTime            = 0,
                fCalStartTime       = 0;
    ViChar      error_message[256];
    ViSession   io;

    /* Define remote connection parameters (as default values) */

    ViBoolean   IDQuery             = VI_TRUE,
                resetDevice         = VI_TRUE;
    ViRsrc      resourceName        = RESOURCE_NAME;

    CHECKERR (rssiam_init (resourceName, IDQuery, resetDevice, &io));

    printf (

    "\n --- Set Independent Channel Parameters ---------------------------------\n\n"
    "\t CH1:\n\n"
    "\t - Frequency: 700.0 Hz\n"
    "\t - Function: Square\n\n"
    "\t CH2:\n\n"
    "\t - Frequency: 2400.0 Hz\n"
    "\t - Function: Sine\n"
    "\n ------------------------------------------------------------------------\n\n"

    );

    CHECKERR (rssiam_outpChannelCoupl (io, RSSIAM_CHANNEL_COUPLING_OFF));

    /* --- CH1 --- */
    CHECKERR (rssiam_outpChannel (io, RSSIAM_CH1));
    CHECKERR (rssiam_freq (io, 700.0));
    CHECKERR (rssiam_funcShap (io, RSSIAM_OUTPUT_FUNC_SQU));
    CHECKERR (rssiam_outpSetup (io, RSSIAM_OUTPUT_SETUP_ON));

    /* --- CH2 --- */
    CHECKERR (rssiam_outpChannel (io, RSSIAM_CH2));
    CHECKERR (rssiam_freq (io, 2400.0));
    CHECKERR (rssiam_funcShap (io, RSSIAM_OUTPUT_FUNC_SIN));
    CHECKERR (rssiam_outpSetup (io, RSSIAM_OUTPUT_SETUP_ON));

    printf ("\n");

    CHECKERR (rssiam_close (io));

    return 0;
}
